==> finwise_python-1.1.2.tar.gz: finwise_python-1.1.2/CHANGELOG.md <==
# CHANGELOG

<!-- version list -->

## v1.1.2 (2026-01-08)

### Bug Fixes

- Package should match pypi project
  ([`e728290`](https://github.com/rameezk/finwise-python/commit/e72829044770e33094f344ff4b41575d41459808))

### Documentation

- Update readme
  ([`c70346f`](https://github.com/rameezk/finwise-python/commit/c70346f70a98a97ab385340149acba7cf0580d3d))


## v1.1.1 (2026-01-08)

### Bug Fixes

- Disable attestations for PyPI publish
  ([`fda0a27`](https://github.com/rameezk/finwise-python/commit/fda0a2709d15ff933857b31572593a6bf602118c))


## v1.1.0 (2026-01-08)

### Features

- Publish to pypi
  ([`36594a6`](https://github.com/rameezk/finwise-python/commit/36594a640f28efa58f38ff48ba17a35268d7ea92))


## v1.0.0 (2026-01-08)

### Features

- Use auto detection for version bumping
  ([`96f0039`](https://github.com/rameezk/finwise-python/commit/96f0039ed82b7bb1e1f2adb2c3fcb26f2a5c7fa6))


## v0.2.2 (2026-01-08)

### Features

- Run CI checks before release
  ([`d531d5a`](https://github.com/rameezk/finwise-python/commit/d531d5a7aab0d8981329b9c497daf6389ce8760d))


## v0.2.1 (2026-01-08)

### Bug Fixes

- Remove redundant release step from workflow
  ([`8615582`](https://github.com/rameezk/finwise-python/commit/8615582c62fe1304b8bb546cefa5b6ff49aaa63c))


## v0.2.0 (2026-01-08)


## v0.1.1 (2026-01-08)

### Features

- Add release workflow
  ([`cfb1e53`](https://github.com/rameezk/finwise-python/commit/cfb1e533e3a0d17f64de3ae451ef6d9078f16d6e))


## v0.1.0 (2026-01-08)

- Initial Release

==> finwise_python-1.1.3.tar.gz: finwise_python-1.1.3/CHANGELOG.md <==
# CHANGELOG

<!-- version list -->

## v1.1.3 (2026-01-09)

### Documentation

- Add contributing.md
  ([`900ed2f`](https://github.com/rameezk/finwise-python/commit/900ed2f25a82e6cb8d6cce75ffbfbe317e890903))

- Add issue templates
  ([`2db057e`](https://github.com/rameezk/finwise-python/commit/2db057e3100787ef70c27521fd3cbe218c084709))

- Update readme
  ([`9683d8f`](https://github.com/rameezk/finwise-python/commit/9683d8f1fc5d251a8fd5f8c530c0da4aa2e6d252))

- Update readme
  ([`380c2d9`](https://github.com/rameezk/finwise-python/commit/380c2d9624f240c67da1bd85beb50abe4b42450c))

- Update readme
  ([`cd5a86d`](https://github.com/rameezk/finwise-python/commit/cd5a86d3ec903c968447fb7b7e05a683cebddc23))


## v1.1.2 (2026-01-08)

### Bug Fixes

- Package should match pypi project
  ([`e728290`](https://github.com/rameezk/finwise-python/commit/e72829044770e33094f344ff4b41575d41459808))

### Documentation

- Update readme
  ([`c70346f`](https://github.com/rameezk/finwise-python/commit/c70346f70a98a97ab385340149acba7cf0580d3d))


## v1.1.1 (2026-01-08)

### Bug Fixes

- Disable attestations for PyPI publish
  ([`fda0a27`](https://github.com/rameezk/finwise-python/commit/fda0a2709d15ff933857b31572593a6bf602118c))


## v1.1.0 (2026-01-08)

### Features

- Publish to pypi
  ([`36594a6`](https://github.com/rameezk/finwise-python/commit/36594a640f28efa58f38ff48ba17a35268d7ea92))


## v1.0.0 (2026-01-08)

### Features

- Use auto detection for version bumping
  ([`96f0039`](https://github.com/rameezk/finwise-python/commit/96f0039ed82b7bb1e1f2adb2c3fcb26f2a5c7fa6))


## v0.2.2 (2026-01-08)

### Features

- Run CI checks before release
  ([`d531d5a`](https://github.com/rameezk/finwise-python/commit/d531d5a7aab0d8981329b9c497daf6389ce8760d))


## v0.2.1 (2026-01-08)

### Bug Fixes

- Remove redundant release step from workflow
  ([`8615582`](https://github.com/rameezk/finwise-python/commit/8615582c62fe1304b8bb546cefa5b6ff49aaa63c))


## v0.2.0 (2026-01-08)


## v0.1.1 (2026-01-08)

### Features

- Add release workflow
  ([`cfb1e53`](https://github.com/rameezk/finwise-python/commit/cfb1e533e3a0d17f64de3ae451ef6d9078f16d6e))


## v0.1.0 (2026-01-08)

- Initial Release
